import os, sys
import datetime

from bs4 import BeautifulSoup
from urllib.parse import unquote

from RAAspotter import RAAspotter

class RAAspotter_pref13(RAAspotter):

  # Config
  __HOST       = 'https://www.bouches-du-rhone.gouv.fr'
  __RAA_PAGE   = [f'{__HOST}/Publications/RAA-et-Archives/RAA-2024',
                  f'{__HOST}/Publications/RAA-et-Archives/RAA-2023',
                  f'{__HOST}/Publications/RAA-et-Archives/Archives-RAA-des-Bouches-du-Rhone/RAA-2022',
                  f'{__HOST}/Publications/RAA-et-Archives/Archives-RAA-des-Bouches-du-Rhone/RAA-2021',
                  f'{__HOST}/Publications/RAA-et-Archives/Archives-RAA-des-Bouches-du-Rhone/RAA-2020',
                  f'{__HOST}/Publications/RAA-et-Archives/Archives-RAA-des-Bouches-du-Rhone/RAA-2019']
  __USER_AGENT = 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/122.0.0.0 Safari/537.36'
  full_name = 'Préfecture des Bouches-du-Rhône'
  short_code = 'pref13'

  def __init__(self, data_dir):
    super().__init__(data_dir, self.__USER_AGENT)
    self.enable_tor(10)

  def get_raa(self, keywords):
    self.print_output('RAAspotter_pref13')
    self.print_output(f'Termes recherchés: {keywords}')
    self.print_output('')

    for raa_page in self.__RAA_PAGE:
      page_content = self.get_page(raa_page).content
      raa_elements = self.get_raa_elements(page_content)
      self.parse_raa(raa_elements, keywords.split(','))

    self.mailer()

  def get_raa_elements(self, page_content):
    elements = []
    # On charge le parser
    soup = BeautifulSoup(page_content, 'html.parser')

    # Pour chaque balise a, on regarde si c'est un PDF, et si oui on le parse
    for a in soup.find_all('a', href=True, class_='fr-link--download'):
      if a['href'].endswith('.pdf'):
        if a['href'].startswith('/'):
          url = f"{self.__HOST}{a['href']}"
        else:
          url = a['href']

        url      = unquote(url)
        name     = a.find('span').previous_sibling.replace('Télécharger ', '').strip()
        date     = datetime.datetime.strptime(a.find('span').get_text().split(' - ')[-1].strip(), '%d/%m/%Y')
        filename = unquote(url.split('/')[-1])

        raa = RAAspotter.RAA(url, date, name, filename)
        elements.append(raa)
    return elements
